@@ -14,7 +14,7 @@ from PIL import Image
 import pretty_errors
 import pysnooper
 
-from cqrcode.app.static_data import data64, data128, data256, \
+from cqrcode.static_data import data64, data128, data256, \
     dataPath, standard_module_table, Alphanumeric_mode_table, capacity_of_each_qrcode
 from cqrcode.app.prepare_data import data_decode, data_encode, \
     random_bit
